==> aspose_cad_cloud-20.11.0-py3-none-any.whl: asposecadcloud/__init__.py <==
#  coding: utf-8
#  ----------------------------------------------------------------------------
#  <copyright company="Aspose" file="__init__.py">
#    Copyright (c) 2018-2019 Aspose Pty Ltd. All rights reserved.
#  </copyright>
#  <summary>
#    Permission is hereby granted, free of charge, to any person obtaining a
#   copy  of this software and associated documentation files (the "Software"),
#   to deal  in the Software without restriction, including without limitation
#   the rights  to use, copy, modify, merge, publish, distribute, sublicense,
#   and/or sell  copies of the Software, and to permit persons to whom the
#   Software is  furnished to do so, subject to the following conditions:
#
#   The above copyright notice and this permission notice shall be included in
#   all  copies or substantial portions of the Software.
#
#   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#   IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#   FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#   AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#   LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
#   FROM,  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
#   DEALINGS IN THE SOFTWARE.
#  </summary>
#  ----------------------------------------------------------------------------

from __future__ import absolute_import

# import apis into sdk package
from asposecadcloud.api.cad_api import CadApi

# import ApiClient
from asposecadcloud.api_client import ApiClient
from asposecadcloud.configuration import Configuration
# import models into sdk package
from asposecadcloud.models.cad_response import CadResponse
from asposecadcloud.models.cff2_properties import Cff2Properties
from asposecadcloud.models.color import Color
from asposecadcloud.models.dgn_properties import DgnProperties
from asposecadcloud.models.disc_usage import DiscUsage
from asposecadcloud.models.drawing_options_base_dto import DrawingOptionsBaseDTO
from asposecadcloud.models.dwf_properties import DwfProperties
from asposecadcloud.models.dwg_properties import DwgProperties
from asposecadcloud.models.dxf_properties import DxfProperties
from asposecadcloud.models.error import Error
from asposecadcloud.models.error_details import ErrorDetails
from asposecadcloud.models.file_versions import FileVersions
from asposecadcloud.models.files_list import FilesList
from asposecadcloud.models.files_upload_result import FilesUploadResult
from asposecadcloud.models.graphics_options import GraphicsOptions
from asposecadcloud.models.ifc_properties import IfcProperties
from asposecadcloud.models.igs_properties import IgsProperties
from asposecadcloud.models.object_exist import ObjectExist
from asposecadcloud.models.pdf_document_info import PdfDocumentInfo
from asposecadcloud.models.pdf_document_options import PdfDocumentOptions
from asposecadcloud.models.pen_options import PenOptions
from asposecadcloud.models.rd_optimizer_settings import RdOptimizerSettings
from asposecadcloud.models.resolution_setting import ResolutionSetting
from asposecadcloud.models.stl_properties import StlProperties
from asposecadcloud.models.storage_exist import StorageExist
from asposecadcloud.models.storage_file import StorageFile
from asposecadcloud.models.vector_rasterization_options_dto import VectorRasterizationOptionsDTO
from asposecadcloud.models.bmp_options_dto import BmpOptionsDTO
from asposecadcloud.models.cad_rasterization_options_dto import CadRasterizationOptionsDTO
from asposecadcloud.models.file_version import FileVersion
from asposecadcloud.models.gif_options_dto import GifOptionsDTO
from asposecadcloud.models.jpeg2000_options_dto import Jpeg2000OptionsDTO
from asposecadcloud.models.jpeg_options_dto import JpegOptionsDTO
from asposecadcloud.models.pdf_options_dto import PdfOptionsDTO
from asposecadcloud.models.png_options_dto import PngOptionsDTO
from asposecadcloud.models.psd_options_dto import PsdOptionsDTO
from asposecadcloud.models.svg_options_dto import SvgOptionsDTO
from asposecadcloud.models.tiff_options_dto import TiffOptionsDTO
from asposecadcloud.models.wmf_options_dto import WmfOptionsDTO

==> aspose_cad_cloud-24.1.0-py3-none-any.whl: asposecadcloud/__init__.py <==
#  coding: utf-8
#  ----------------------------------------------------------------------------
#  <copyright company="Aspose" file="__init__.py">
#    Copyright (c) 2018-2019 Aspose Pty Ltd. All rights reserved.
#  </copyright>
#  <summary>
#    Permission is hereby granted, free of charge, to any person obtaining a
#   copy  of this software and associated documentation files (the "Software"),
#   to deal  in the Software without restriction, including without limitation
#   the rights  to use, copy, modify, merge, publish, distribute, sublicense,
#   and/or sell  copies of the Software, and to permit persons to whom the
#   Software is  furnished to do so, subject to the following conditions:
#
#   The above copyright notice and this permission notice shall be included in
#   all  copies or substantial portions of the Software.
#
#   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#   IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#   FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#   AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#   LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
#   FROM,  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
#   DEALINGS IN THE SOFTWARE.
#  </summary>
#  ----------------------------------------------------------------------------

from __future__ import absolute_import

# import apis into sdk package
from asposecadcloud.api.cad_api import CadApi

# import ApiClient
from asposecadcloud.api_client import ApiClient
from asposecadcloud.configuration import Configuration
# import models into sdk package
from asposecadcloud.models.asn_encoded_data import AsnEncodedData
from asposecadcloud.models.asymmetric_algorithm import AsymmetricAlgorithm
from asposecadcloud.models.cad_response import CadResponse
from asposecadcloud.models.cf2_properties import Cf2Properties
from asposecadcloud.models.color import Color
from asposecadcloud.models.dgn_properties import DgnProperties
from asposecadcloud.models.disc_usage import DiscUsage
from asposecadcloud.models.drawing_options_base_dto import DrawingOptionsBaseDTO
from asposecadcloud.models.dwf_properties import DwfProperties
from asposecadcloud.models.dwg_properties import DwgProperties
from asposecadcloud.models.dxf_properties import DxfProperties
from asposecadcloud.models.error import Error
from asposecadcloud.models.error_details import ErrorDetails
from asposecadcloud.models.fbx_properties import FbxProperties
from asposecadcloud.models.file_versions import FileVersions
from asposecadcloud.models.files_list import FilesList
from asposecadcloud.models.files_upload_result import FilesUploadResult
from asposecadcloud.models.graphics_options import GraphicsOptions
from asposecadcloud.models.ifc_properties import IfcProperties
from asposecadcloud.models.igs_properties import IgsProperties
from asposecadcloud.models.int_ptr import IntPtr
from asposecadcloud.models.key_sizes import KeySizes
from asposecadcloud.models.obj_properties import ObjProperties
from asposecadcloud.models.object_exist import ObjectExist
from asposecadcloud.models.oid import Oid
from asposecadcloud.models.pdf_digital_signature_details_core import PdfDigitalSignatureDetailsCore
from asposecadcloud.models.pdf_document_info import PdfDocumentInfo
from asposecadcloud.models.pdf_document_options import PdfDocumentOptions
from asposecadcloud.models.pen_options import PenOptions
from asposecadcloud.models.plt_properties import PltProperties
from asposecadcloud.models.public_key import PublicKey
from asposecadcloud.models.rd_optimizer_settings import RdOptimizerSettings
from asposecadcloud.models.resolution_setting import ResolutionSetting
from asposecadcloud.models.stl_properties import StlProperties
from asposecadcloud.models.storage_exist import StorageExist
from asposecadcloud.models.storage_file import StorageFile
from asposecadcloud.models.vector_rasterization_options_dto import VectorRasterizationOptionsDTO
from asposecadcloud.models.watermark_rgb import WatermarkRGB
from asposecadcloud.models.x509_certificate import X509Certificate
from asposecadcloud.models.bmp_options_dto import BmpOptionsDTO
from asposecadcloud.models.cad_rasterization_options_dto import CadRasterizationOptionsDTO
from asposecadcloud.models.cgm_options_dto import CgmOptionsDTO
from asposecadcloud.models.dwf_options_dto import DwfOptionsDTO
from asposecadcloud.models.dxf_options_dto import DxfOptionsDTO
from asposecadcloud.models.fbx_options_dto import FbxOptionsDTO
from asposecadcloud.models.file_version import FileVersion
from asposecadcloud.models.gif_options_dto import GifOptionsDTO
from asposecadcloud.models.glb_options_dto import GlbOptionsDTO
from asposecadcloud.models.gltf_options_dto import GltfOptionsDTO
from asposecadcloud.models.jpeg2000_options_dto import Jpeg2000OptionsDTO
from asposecadcloud.models.jpeg_options_dto import JpegOptionsDTO
from asposecadcloud.models.obj_options_dto import ObjOptionsDTO
from asposecadcloud.models.pdf_options_dto import PdfOptionsDTO
from asposecadcloud.models.png_options_dto import PngOptionsDTO
from asposecadcloud.models.psd_options_dto import PsdOptionsDTO
from asposecadcloud.models.stp_options_dto import StpOptionsDTO
from asposecadcloud.models.svg_options_dto import SvgOptionsDTO
from asposecadcloud.models.three_ds_options_dto import ThreeDSOptionsDTO
from asposecadcloud.models.tiff_options_dto import TiffOptionsDTO
from asposecadcloud.models.u3d_options_dto import U3dOptionsDTO
from asposecadcloud.models.wmf_options_dto import WmfOptionsDTO
from asposecadcloud.models.x500_distinguished_name import X500DistinguishedName
from asposecadcloud.models.x509_certificate2 import X509Certificate2
